CompositorCapabilities

Struct CompositorCapabilities 

#[repr(C)]
pub struct CompositorCapabilities { pub virtual_surface_size: i32, pub redraw_on_invalidation: bool, pub max_update_rects: usize, pub supports_surface_for_backdrop: bool, pub supports_external_compositor_surface_negative_scaling: bool, }

Fields

virtual_surface_size: i32

The virtual surface size used by the underlying platform.

redraw_on_invalidation: bool

Whether the compositor requires redrawing on invalidation.

max_update_rects: usize

The maximum number of dirty rects that can be provided per compositor surface update. If this is zero, the entire compositor surface for a given tile will be drawn if it’s dirty.

supports_surface_for_backdrop: bool

Whether or not this compositor will create surfaces for backdrops.

supports_external_compositor_surface_negative_scaling: bool

Whether external compositor surface supports negative scaling.